ui <- fluidPage(theme = shinytheme("spacelab"),
  useShinyjs(),
  titlePanel("Cálculo de la Energía Firme en Plantas Eólicas", windowTitle = "ENFICC - Energía Eólica"),
  includeCSS("www/slider.css"),
  tags$style(HTML("::selection {background: tomato}")),
  tags$link(rel="shortcut icon", href="./iconoENFICC.bmp"),
  
  navbarPage(title="ENFICC - Energía Eólica",
             tabPanel("Introducción y Guía de Uso",
                      fluidRow(
                        column(3,wellPanel(
                          h4("Guía de Usuario para ENFICC - Energía Eólica"),
                          a("Actualización 1.0", href="#actualizacion1"),br(),
                          # a("Formato de los Datos de Entrada", href = "#dataformats"), br(),
                          a("¿Cómo Funciona el Aplicativo?", href = "#funcionamiento"), br(),
                          a("Ejecución del Parque de Prueba", href="#parqueprueba"), br()
                          # a("Ayuda e Información", href = "#help"), br()
                        )
                        ),#column
                        column(9,includeMarkdown("www/landing.md"))
                      )),
             
             tabPanel("Carga y Visualización de Datos: Mediciones en Sitio",
                      br(),
                      fluidRow(
                        wellPanel(
                          textInput(inputId="NumTorres", label = "Ingrese el número de torres instaladas en el área del parque eólico
                                    (Valor Entero)",
                                    "1", width="35%")
                        ),
                        wellPanel(
                          p(
                            actionButton("Ingresar_Info", label = "Ingresar Información de Torres")
                          ),
                          shinyjs::hidden(
                            div(id = "IngresarInfo", sidebarLayout(fluid=TRUE, 
                                                                   div(sidebarPanel(uiOutput("UI_C_TORRES"))),
                                                                   mainPanel(uiOutput("UI_V_TORRES"))
                                                                   )
                            )
                          )
                        ) 
                      )
             ),
             
             tabPanel("Carga y Visualización de Datos: Parque, Turbinas y Fuente Secundaria",
                      sidebarLayout(fluid=TRUE,
                                    div(sidebarPanel(
                                          ########## PARQUE EÓLICO
                                          br(),
                                          tags$div(id="POCSBO", h4("PARQUE EÓLICO:"),
                                                   fileInput(inputId="Parque_eolico", label = "Cargue el archivo .csv con la ubicación de las turbinas
                                                             del parque eólico (coordenadas de longitud, latitud y altitud sobre el nivel del mar).",
                                                             multiple = FALSE, accept = c(".csv"), buttonLabel = "Explorar..."),
                                                   tags$div(
                                                     HTML("Especifique las alturas de cubo de las turbinas instaladas:")
                                                   ), br(),
                                                   p(
                                                     actionButton("Uno_Cubo", label = "Alturas de Cubo IGUALES")
                                                   ),
                                                   shinyjs::hidden(
                                                     div(id = "UnoCubo", 
                                                         textInput(inputId="Altura_Cubo", label = "¿Cuál es la altura del cubo de las turbinas del parque eólico [m]?",
                                                                   "Valor con punto decimal")
                                                     )
                                                   ),
                                                   p(
                                                     actionButton("Varios_Cubo", label = "Alturas de Cubo DIFERENTES")
                                                   ),
                                                   shinyjs::hidden(
                                                     div(id = "VariosCubo", 
                                                         fileInput(inputId="Varias_Alt_Cubo", label = "Cargue un archivo .csv con las alturas de cubo correspondientes a cada turbina eólica
                                                                   en el mismo orden del archivo del parque eólico.",
                                                                   multiple = FALSE, accept = c(".csv"), buttonLabel = "Explorar...")
                                                     )
                                                   ),
                                                   textInput(inputId="Diam_Turb", label = "¿Cuál es diámetro de las turbinas eólicas del parque eólico [m]?",
                                                             "Valor con punto decimal"),
                                                   selectInput(inputId="On_Offshore", label  = "¿El parque eólico se encuentra dentro o fuera de costa?", 
                                                               choices = c("Dentro de Costa (k = 0.075)", "Fuera de Costa (k = 0.04)"), multiple = FALSE),
                                                   tags$div(
                                                     HTML("Si desea incluir el cálculo por pérdidas eléctricas, haga clic en el siguiente botón e ingrese la información solicitada:")
                                                   ),
                                                   p(
                                                     actionButton("Perdidas_Electricas", label = "Calcular Pérdidas Eléctricas")
                                                   ),
                                                   shinyjs::hidden(
                                                     div(id = "PerdidasElectricas",
                                                         tags$div(
                                                           HTML("A continuación, ingrese la ubicación del Punto de Conexión Común (PCC) en coordenadas geográficas (grados decimales) y altitud topográfica [m]:")
                                                         ),
                                                         splitLayout(
                                                           textInput(inputId="LongPCC", label = "Longitud",
                                                                     "Valor con punto decimal"),
                                                           textInput(inputId="LatPCC", label = "Latitud",
                                                                     "Valor con punto decimal"),
                                                           textInput(inputId="AltPCC", label = "Altitud [m]",
                                                                     "Valor con punto decimal")
                                                         ),
                                                         fileInput(inputId="Cableado", label = "Cargue el archivo .csv con el cableado del parque eólico. Cada columna debe representar un cable del trazado eléctrico y 
                                                                   dentro de cada columna se especifican las turbinas conectadas por un cable determinado (usando los mísmos índices del Parque Eólico), 
                                                                   ordenadas desde la turbina más lejana hasta la más cercana con respecto al PCC.",
                                                                   multiple = FALSE, accept = c(".csv"), buttonLabel = "Explorar..."),
                                                         splitLayout(
                                                           textInput(inputId="Resistencia", label = HTML("Resistencia del cableado en &Omega;/km:"),
                                                                     "Valor con punto decimal"),
                                                           textInput(inputId="Voltaje", label = HTML("Voltaje del transformador en kV:"),
                                                                     "Valor con punto decimal")
                                                           
                                                         )
                                                     )
                                                   ),
                                                   p(
                                                     actionButton("Grandes_Parques", label = "Incluir Corrección de Grandes Parques (EXPERIMENTAL)")
                                                   ),
                                                   shinyjs::hidden(
                                                     div(id = "GrandesParques",
                                                         tags$div(
                                                           HTML("Este modelo de corrección de la velocidad debido al fenómeno de grandes parques se encuentra en proceso de validación. 
                                                                Los autores del modelo (Garrad Hasan) han validado su uso en parques fuera de costa, mientras que para el caso dentro de costa,
                                                                todavía no se conoce el alcance del modelo con precisión. En este aplicativo se implementa este método basado en la mayor 
                                                                información disponible en manuales y consultas puntuales con GH, por lo que el uso de esta herramienta es experimental y debe ser
                                                                utilizada con cautela.")
                                                         ),
                                                         textInput(inputId="Rugosidad_Aumentada", label = HTML("Seleccione la rugosidad aumentada por las turbinas del parque. Un incremento de la rugosidad entre 0.02 m y 0.05 m
                                                                                                               ha mostrado tener los mejores resultados, donde 0.03 m es el valor más recomendado para fuera de costa y 0.05 m
                                                                                                               el más recomendado para dentro de costa."),
                                                                   "Valor con punto decimal"),
                                                         selectInput(inputId="Cortante_Parques", label  = "Defina si la rugosidad del terreno a utilizar corresponderá a valores por defecto 
                                                                     (0.0002 m para fuera de costa, 0.055 m para fuera de costa) o será calculado a partir del cortante de viento en sitio.", 
                                                                     choices = c("Valores por Defecto", "Cálculo a partir de Cortante de Viento en Sitio"), multiple = FALSE)
                                                     )
                                                   )
                                                   ),
                                          ########## CURVA POTENCIA EMPUJE
                                          br(),
                                          tags$div(id="POCSBO1", h4("CURVAS DE POTENCIA Y EMPUJE:"),
                                                   fileInput(inputId="Curva_Potencia_Empuje", label = "Cargue el archivo .csv con la curva de potencia y empuje
                                                             de las turbinas utilizadas en el parque eólico.",multiple = FALSE, accept = c(".csv"), buttonLabel = "Explorar..."),
                                                   textInput(inputId="rho_fabricante", label = "¿Cuál es la densidad del aire (unidades S.I.) usada en las curvas del fabricante?",
                                                             "Valor con punto decimal"),
                                                   textInput(inputId="Pot_nominal", label = "¿Cuál es Potencia Nominal de la turbina [kW]?",
                                                             "Valor con punto decimal"),
                                                   textInput(inputId="Vel_Entrada", label = "¿Cuál es la velocidad de entrada de la turbina [m/s]?",
                                                             "Valor con punto decimal"),
                                                   textInput(inputId="Vel_Salida", label = "¿Cuál es la velocidad de salida de la turbina [m/s]?",
                                                             "Valor con punto decimal"),
                                                   textInput(inputId="Temp_Min", label = "¿Cuál es la temperatura mínima de operación de la turbina [°C]?",
                                                             "Valor con punto decimal"),
                                                   textInput(inputId="Temp_Max", label = "¿Cuál es la temperatura máxima de operación de la turbina [°C]?",
                                                             "Valor con punto decimal")
                                                   ),
                                          ########## FUENTE SECUNDARIA
                                          br(),
                                          tags$div(id="POCSBO3", h4("FUENTE SECUNDARIA:"),
                                                   fileInput(inputId="fuente_secundaria", label = "Cargue el archivo .csv con la fuente secundaria de velocidad y dirección del viento 
                                                             para por lo menos 10 años.",multiple = FALSE, accept = c(".csv"), buttonLabel = "Explorar..."),
                                                   fileInput(inputId="comun_secundaria", label = "Cargue el archivo .csv con la fuente secundaria de velocidad y dirección del viento 
                                                             para el período en común con las mediciones en sitio.",multiple = FALSE, accept = c(".csv"), buttonLabel = "Explorar..."),
                                                   textInput(inputId="Alt_secundaria", label = "Altura de la fuente secundaria de Velocidad/Dirección [m]",
                                                             "Valor con punto decimal")
                                                   )
                                        )
                                        ),
                                    
                                    mainPanel(
                                      tabsetPanel(
                                        tabPanel("Parque Eólico y Torres Meteorológicas",
                                                 wellPanel(
                                                   p(
                                                     actionButton("MostrarParque","Mostrar Mapa Satelital de las Turbinas del Parque Eólico"),
                                                     br()
                                                   ),
                                                   
                                                   shinyjs::hidden(
                                                     div(id = "ParqueDiv", 
                                                         plotOutput("parqueEolico.plot", width = "90%", height = "720px"), br(),
                                                         actionButton("ZoomParque","Alejar Vista del Parque"),
                                                         shinyjs::hidden(
                                                           div(id = "ZParqueDiv",
                                                               plotOutput("ZparqueEolico.plot", width = "90%", height = "720px")
                                                           )
                                                         )
                                                         )
                                                   )
                                                 ),
                                                 wellPanel(
                                                   p(
                                                     actionButton("MostrarTrazado","Mostrar Mapa Satelital del Trazado Eléctrico del Parque Eólico"),
                                                     br()
                                                   ),
                                                   
                                                   shinyjs::hidden(
                                                     div(id = "TrazadoDiv", 
                                                         plotOutput("trazadoElectrico.plot", width = "90%", height = "720px"), br(),
                                                         actionButton("ZoomTrazado","Alejar Vista del Trazado"),
                                                         shinyjs::hidden(
                                                           div(id = "ZTrazadoDiv",
                                                               plotOutput("ZtrazadoElectrico.plot", width = "90%", height = "720px")
                                                           )
                                                         )
                                                         )
                                                   )
                                                 ),
                                                 wellPanel(
                                                   p(
                                                     actionButton("MostrarTorres","Mostrar Mapa Satelital de las Torres del Parque Eólico"),
                                                     br()
                                                   ),
                                                   
                                                   shinyjs::hidden(
                                                     div(id = "TorresMap", 
                                                         plotOutput("torresMap.plot", width = "90%", height = "720px"), br(),
                                                         actionButton("ZoomTorres","Alejar Vista del Mapa"),
                                                         shinyjs::hidden(
                                                           div(id = "ZTorreDiv",
                                                               plotOutput("ZtorresMap.plot", width = "90%", height = "720px")
                                                           )
                                                         )
                                                         )
                                                   )
                                                 ),
                                                 wellPanel(
                                                   p(
                                                     actionButton("TablaParque","Mostrar Tabla con Datos del Parque"),
                                                     br()
                                                   ),
                                                   
                                                   shinyjs::hidden(
                                                     div(id = "ParqueTabDiv", h4("Tabla de Datos de Parque Eólico"),
                                                         DT::dataTableOutput("parqueEolico.out", width = "100%")
                                                     )
                                                   )
                                                 )
                                        ),
                                        tabPanel("Curvas de Potencia y Empuje",
                                                 wellPanel(
                                                   p(
                                                     actionButton("MostrarCurvas","Mostrar Curvas de Potencia y Empuje"),
                                                     br()
                                                   ),
                                                   
                                                   shinyjs::hidden(
                                                     div(id = "CurvaDiv",
                                                         plotOutput("curvas.plot", width = "100%", height = "1200px")
                                                     )
                                                   )
                                                 ),
                                                 wellPanel(
                                                   p(
                                                     actionButton("TablaCurva","Mostrar Tabla con Datos de las Curvas"),
                                                     br()
                                                   ),
                                                   
                                                   shinyjs::hidden(
                                                     div(id = "CurvaTabDiv", h4("Tabla de Datos de Curvas de Potencia y Empuje"),
                                                         DT::dataTableOutput("curvas.out", width = "100%", height = "1200px")
                                                     )
                                                   )
                                                 )
                                        ),
                                        tabPanel("Visualización de Datos De Fuente Secundaria",
                                                 br(),
                                                 fluidRow(
                                                   wellPanel(
                                                     p(
                                                       actionButton("RGUI_SEC", label = "Velocidad y Dirección: Fuente Secundaria"),
                                                       br()
                                                     ),
                                                     shinyjs::hidden(
                                                       div(id = "RGUISEC", h4("Velocidad y Dirección: Fuente Secundaria"),
                                                           plotOutput("secundaria.plot", width = "100%", height = "1800px")
                                                       )
                                                     )
                                                   ),
                                                   wellPanel(
                                                     p(
                                                       actionButton("TablaSecundaria","Visualización de Tablas de Fuente Secundaria"),
                                                       br()
                                                     ),
                                                     shinyjs::hidden(
                                                       div(id = "VientoTabSec",
                                                           h4("Tablas de Datos de Fuente Secundaria para 10 años (o superior)"), DT::dataTableOutput("datos_sec.out", width = "100%"),
                                                           h4("Tablas de Datos de Fuente Secundaria para el Período Común"), DT::dataTableOutput("datos_secomun.out", width = "100%")
                                                       )
                                                     )
                                                   )
                                                 )
                                        )
                                      )
                                    )
                                   )
             ),
             
             tabPanel("Cálculo y Descarga de Resultados",
                      navlistPanel(
                        tabPanel("Paso 1: Densidad en Sitio y Corrección de Curvas de Potencia y Empuje por Densidad",
                                 fluidRow(
                                   wellPanel(
                                     p(
                                       actionButton("RGUI_Densidad", label = "Calcular Densidad en Sitio a la Altura del Cubo"),
                                       br()
                                     ),
                                     
                                     shinyjs::hidden(
                                       div(id = "RGUIDensidad", h2("Densidad en Sitio"), align="center",
                                           uiOutput("UIdensidad")
                                       )
                                     )
                                   ),
                                   
                                   wellPanel(
                                     p(
                                       actionButton("RGUI_CurvaCorr", label = "Corrección de Curvas por Densidad"),
                                       br()
                                     ),
                                     
                                     shinyjs::hidden(
                                       div(id = "RGUICurvaCorr", h2("Curvas Corregidas por Densidad"),
                                           uiOutput("UICorrecciones")
                                           )
                                       )
                                     )
                                 )
                        ),
                        
                        tabPanel("Paso 2: Cálculo de Cortante del Viento",
                                 fluidRow(
                                   wellPanel(
                                     selectInput(inputId="Metodo_Alpha", label  = "¿Qué método prefiere para el cálculo del coeficiente de cortante de viento?", 
                                                 choices = c("Dos Alturas", "Tres Alturas", "Justus-Mikhail"), multiple = FALSE),
                                     tags$div(
                                       HTML("Tenga en cuenta que si selecciona el método 'Tres alturas', el aplicativo se demorará más de un minuto en ejecutarse. 
                                            En este caso, espere hasta que se muestren las gráficas de cortante de viento, las cuales confirmarán la finalización del proceso.")
                                     ),
                                     br(),
                                     tags$div(
                                       HTML(paste(tags$span(style="color:red", "RECUERDE: "), "Si ya implementó este cálculo en una ocasión anterior y ya posee información descargada del cortante de viento en sitio,
                                            puede omitir la ejecución de este paso.", sep = ""))
                                     ),
                                     p(
                                       br(),
                                       actionButton("RGUI_Alpha", label = "Calcular el Coeficiente de Cortante del Viento en el Sitio"),
                                       br()
                                     ),
                                     
                                     shinyjs::hidden(
                                       div(id = "RGUIAlpha", h4("Coeficiente Cortante del Viento en Sitio"),
                                           uiOutput("UIAlpha")
                                          )
                                     )
                                   )
                                 )
                        ),
                        
                        tabPanel("Paso 3: Extrapolación Temporal de Velocidad y Dirección (MCP)",
                                 fluidRow(
                                   wellPanel(
                                     tags$div(
                                       HTML(paste(tags$span(style="color:red", "RECUERDE: "), "Si ya ejecutó el Paso 2 en una ocasión anterior y ya posee información del cortante
                                                  de viento en sitio, puede subir el archivo .csv haciendo clic en el siguiente botón.", sep = ""))
                                     ),
                                     p(
                                       actionButton("Subir_Alpha", label = "Subir Archivo con Cortante de Viento en Sitio"),
                                       br()
                                     ),
                                     shinyjs::hidden(
                                       div(id = "SubirAlpha", uiOutput("uiSubirAlpha")
                                       )
                                     ),
                                     tags$div(
                                       HTML("A continuación, se ejecuta la extrapolación temporal de las mediciones en sitio utilizando MCP. 
                                            La serie de velocidad es seleccionada automáticamente por el aplicativo de forma que se utiliza 
                                            la velocidad medida a la altura más cercana a la altura de la fuente secundaria. Por otra parte, 
                                            la serie de dirección debe ser seleccionada como sea preferido por el usuario. Este proceso puede
                                            tomar varios minutos, espere hasta que se muestren las gráficas correspondientes, las cuales confirmarán la finalización del proceso.")
                                       ),
                                     selectInput(inputId="Nivel_Direccion", label  = "¿Qué nivel de medición va utilizar como referencia para la extrapolación de dirección?", 
                                                 choices = c("Superior", "Inferior"), multiple = FALSE),
                                     tags$div(
                                       HTML(paste(tags$span(style="color:red", "RECUERDE: "), "Si ya implementó este cálculo en una ocasión anterior y ya posee información descargada de la Velocidad Reconstruida,
                                            puede omitir la ejecución de este paso.", sep = ""))
                                     ),
                                     br(),
                                     p(
                                       actionButton("RGUI_MCP", label = "Ejecutar Extrapolación Temporal (MCP)"),
                                       br()
                                     ),
                                     
                                     shinyjs::hidden(
                                       div(id = "RGUIMCP", h2("Ejecución del Algoritmo MCP"),
                                           uiOutput("UIMCPMCP")
                                       )
                                     )
                                   )
                                 )
                        ),
                        
                        tabPanel("Paso 4: Ejecución de Modelo de Parque",
                                 wellPanel(
                                   tags$div(
                                     HTML(paste(tags$span(style="color:red", "RECUERDE: "), "Si ya ejecutó el Paso 2 y el Paso 3 en una ocasión anterior y ya posee información del cortante
                                                  de viento en sitio y la reconstrucción de velocidad y dirección histórica a la altura de referencia, 
                                                puede subir los archivos .csv haciendo clic en el siguiente botón.", sep = ""))
                                   ),
                                   p(
                                     actionButton("Subir_paraEstelas", label = "Subir Archivos Requeridos para la Ejecución de este Paso"),
                                     br()
                                   ),
                                   shinyjs::hidden(
                                     div(id = "SubirparaEstelas", uiOutput("uiSubirESTELA")
                                     )
                                   ),
                                   br(),
                                   tags$div(
                                     HTML("En este paso se ejecuta el cálculo de las velocidades incidentes en cada turbina por el efecto de estela. 
                                          El algoritmo tiene en cuenta la dirección reconstruida para 10 años (o superior), por lo que el aplicativo 
                                          se demorará varios minutos en ejecutarse. En este paso se presentará una gráfica de comparación entre la 
                                          velocidad incidente de una turbina a barlovento y una turbina afectada por estela, la cual indicará la 
                                          finalización del cálculo.")
                                   ),
                                   br(),
                                   tags$div(
                                     HTML("Para observar las velocidades incidentes sin afectar por estelas extrapoladas a la altura del cubo que
                                          serán utilizadas para el cálculo de este paso, haga clic en el siguiente botón y descargue los archivos
                                          correspondientes a cada torre y altura de cubo. (Nota: Si hay varias alturas de cubo así como torres
										  meteorológicas, la descarga puede tomar varios minutos. Espere por favor.)")
                                     ),
                                   p(
                                     actionButton("Velocidad_Extrapolada", label = "Velocidades Incidentes Sin Afectar por Estela"),
                                     br()
                                   ),
                                   shinyjs::hidden(
                                     div(id = "VelocidadExtrapolada", uiOutput("uiVelocidadExtrapolada")
                                     )
                                   ),
                                   br(),
                                   tags$div(
                                     HTML(paste(tags$span(style="color:red", "RECUERDE: "), "Si ya implementó este cálculo en una ocasión anterior y ya posee información descargada de las
                                            Velocidades Incidentes de cada Turbina Afectadas por Estela, puede omitir la ejecución de este paso.", sep = ""))
                                   ),
                                   p(
                                     br(),
                                     actionButton("RGUI_ESTELA", label = "Ejecutar Cálculo de Velocidades Incidentes Afectadas por Estela"),
                                     br()
                                   ),
                                   
                                   shinyjs::hidden(
                                     div(id = "RGUIESTELA", h4("Comparación entre Velocidades Afectadas y No Afectadas"),
                                         plotOutput("comparacionEstela.plot", width = "100%", height = "600px")
                                     )
                                   ),
                                   p(
                                     downloadButton("descargarVelEstelas", "Descargar Velocidades Incidentes por Turbina Afectadas por Estela"),
                                     br()
                                   )
                                 )
                        ),
                        
                        tabPanel("Paso 5: Cálculo de Energía Generada Mensual",
                                 wellPanel(
                                   tags$div(
                                     HTML("En este paso se calcula la Energía Generada por Turbina en MWh en frecuencia
                                          horaria para los 10 años y la Energía Generada Mensual del Parque en MWh/dia.")
                                     ),
                                   tags$div(
                                     HTML(paste(tags$span(style="color:red", "RECUERDE: "), "Si ya ejecutó el Paso 4 en una ocasión anterior y ya posee información de las velocidades de incidencia en cada turbina, 
                                                puede subir el archivo .csv haciendo clic en el siguiente botón.", sep = ""))
                                     ),
                                   p(
                                     actionButton("Subir_Final", label = "Subir Archivo Requerido para la Ejecución de este Paso"),
                                     br()
                                   ),
                                   shinyjs::hidden(
                                     div(id = "SubirFinal",
                                         fileInput(inputId="Vel_TURBINAS", label = "Cargue el archivo .csv que descargó en el botón 
                                                   ''Descargar Velocidades Incidentes por Turbina Afectadas por Estela'' del Paso 4.",
                                                   multiple = FALSE, accept = c(".csv"), buttonLabel = "Explorar...")
                                     )
                                   ),
                                   p(
                                     br(),
                                     actionButton("RGUI_EneFinal", label = "Calcular Energía Generada del Parque Eólico"),
                                     br()
                                   ),
                                   
                                   shinyjs::hidden(
                                     div(id = "RGUIEneFinal", h4("Energía Generada del Parque Eólico"),
                                         plotOutput("energiaMensual.plot", width = "100%", height = "600px"),
                                         div(
                                           splitLayout(
                                             div(
                                               tags$div(
                                                 HTML("El Valor Mínimo de Generación del Parque Eólico en MWh/dia es:")
                                               ),
                                               verbatimTextOutput("ENFICC", placeholder = TRUE),
                                               tags$head(tags$style(HTML("#ENFICC {
                                                                         font-size: 18px;
                                                                         }")))
                                             ),
                                             div(
                                               tags$div(
                                                 HTML("El Mes de Menor Generación fue:")
                                               ),
                                               verbatimTextOutput("ENFICC_Mes", placeholder = TRUE),
                                               tags$head(tags$style(HTML("#ENFICC_Mes {
                                                                         font-size: 18px;
                                                                         }")))
                                             )
                                           )
                                         ), br(),
                                         div(
                                           tags$div(
                                             HTML(paste0(tags$span(style="color:red", "IMPORTANTE: "), "Los siguientes parámetros de la Función de Conversión se calculan a partir de la
                                                  velocidad promedio libre del parque (sin afectar por estela)."))
                                             ),
                                           br(),
                                           splitLayout(
                                             div(
                                               tags$div(
                                                 HTML("La Pendiente de la Función de Conversión es igual a:")
                                               ),
                                               verbatimTextOutput("pendienteLibre_Funcion", placeholder = TRUE),
                                               tags$head(tags$style(HTML("#pendienteLibre_Funcion {
                                                                         font-size: 18px;
                                                                         }")))
                                             ),
                                             div(
                                               tags$div(
                                                 HTML("El Intercepto de la Función de Conversión es igual a:")
                                               ),
                                               verbatimTextOutput("interceptoLibre_Funcion", placeholder = TRUE),
                                               tags$head(tags$style(HTML("#interceptoLibre_Funcion {
                                                                         font-size: 18px;
                                                                         }")))
                                             )
                                           ), br(),
                                           tags$div(
                                             HTML(paste0(tags$span(style="color:red", "IMPORTANTE: "), "Los siguientes parámetros de la Función de Conversión se calculan a partir de la
                                                  velocidad promedio real del parque (afectada por estela)."))
                                           ), br(),
                                           splitLayout(
                                             div(
                                               tags$div(
                                                 HTML("La Pendiente de la Función de Conversión es igual a:")
                                               ),
                                               verbatimTextOutput("pendienteAfectada_Funcion", placeholder = TRUE),
                                               tags$head(tags$style(HTML("#pendienteAfectada_Funcion {
                                                                         font-size: 18px;
                                                                         }")))
                                             ),
                                             div(
                                               tags$div(
                                                 HTML("El Intercepto de la Función de Conversión es igual a:")
                                               ),
                                               verbatimTextOutput("interceptoAfectada_Funcion", placeholder = TRUE),
                                               tags$head(tags$style(HTML("#interceptoAfectada_Funcion {
                                                                         font-size: 18px;
                                                                         }")))
                                             )
                                           )
                                         ),
                                         plotOutput("excendencia", width = "100%", height = "600px"),
                                         div(
                                           tags$div(
                                             HTML("La Capacidad Efectiva Neta (CEN) de la Planta Eólica, al 0.01% PSS [MW]:")
                                           ),
                                           verbatimTextOutput("CEN", placeholder = TRUE),
                                           tags$head(tags$style(HTML("#CEN {
                                                                         font-size: 18px;
                                                                         }")))
                                         ),
                                         tags$div(
                                           HTML("Energía Generada del Parque (Histórico)")
                                         ),
                                         plotOutput("ePH.plot1", width = "100%", height = "600px"),
                                         plotOutput("ePH.plot2", width = "100%", height = "600px"),
                                         plotOutput("ePH.plot3", width = "100%", height = "600px"),
                                         plotOutput("ePH.plot4", width = "100%", height = "600px"),
                                         plotOutput("ePH.plot5", width = "100%", height = "600px")
                                     )
                                   ),
                                   p(
                                     downloadButton("energiaTurbina", "Descargar Energía Horaria Generada por Cada Turbina en MWh"),
                                     br()
                                   ),
                                   p(
                                     downloadButton("energiaHorariaParque", "Descargar Información: Cálculo CEN para Plantas Nuevas en MWh"),
                                     br()
                                   ),
                                   p(
                                     downloadButton("energiaParque", "Descargar Energía Mensual Generada por el Parque en MWh/dia"),
                                     br()
                                   )
                                 )
                        )
                      )
             )
  ),
  tags$footer(includeHTML("www/footer.html"), align = "center")
)
