#' Calcula las distancias de cableado de cada turbina hasta el punto de conexión común
#'
#' @param parqueEolico Parque Eólico
#' @param PCC Punto de Conexiòn Común
#' @param Cableado Trazado Eléctrico
#'
#' @return Distancias por Turbina Eólica
#' @export
#'
#' @examples #Ejemplo

CableDisTurbinas <- function(parqueEolico, PCC, Cableado) {
  if (missing(parqueEolico))
    stop("No hay datos de coordenadas de las turbinas en el parque eólico.")
  if (missing(PCC))
    stop("No hay datos de coordenadas del punto de conexión común.")
  if (missing(Cableado))
    stop("No hay información del trazado eléctrico del parque eólico.")
  #Número de Turbinas
  NT <- length(parqueEolico[[1]])
  #Se refieren las posiciones de las turbinas con respecto al PCC en kilometros
  x_m <- rep(0,NT)
  y_m <- rep(0,NT)
  z_m <- rep(0,NT)
  parqueEnMetros <- data.frame(x_m=x_m, y_m=y_m, z_m=z_m)
  for(i in 1:NT){
    longPCC <- PCC[1]
    longT <- parqueEolico[[2]][i]
    latPCC <- PCC[2]
    latT <- parqueEolico[[3]][i]
    zPCC <- PCC[3]
    zT <- parqueEolico[[4]][i]
    sign_x <- sign(longT - longPCC)
    sign_y <- sign(latT - latPCC)
    ##El método distVincentyEllipsoid calcula la distancia basado en el elipsoide WGS84 como modelo del planeta Tierra
    vecturb <- c((sign_x*distVincentyEllipsoid(c(longT,latPCC),c(longPCC,latPCC))),
                 (sign_y*distVincentyEllipsoid(c(longPCC,latT),c(longPCC,latPCC))))
    parqueEnMetros[[1]][i] <- vecturb[1]/1000
    parqueEnMetros[[2]][i] <- vecturb[2]/1000
    parqueEnMetros[[3]][i] <- (zT - zPCC)/1000
  }
  dist = rep(0,NT)
  for(i in 1:length(Cableado)) {
    cable <- Cableado[[i]]
    distancia <- 0
    x2 <- 0
    y2 <- 0
    z2 <- 0
    for(j in length(cable):1) {
      if(!is.na(cable[j])) {
        cont <- cable[j]
        x1 <- x2
        y1 <- y2
        z1 <- z2
        x2 <- parqueEnMetros[[1]][cont]
        y2 <- parqueEnMetros[[2]][cont]
        z2 <- parqueEnMetros[[3]][cont]
        
        distancia <- distancia + sqrt((x2 - x1)^2 + (y2 - y1)^2 + (z2-z1)^2);
        dist[cont] <- distancia;
      }
    }
  }
  return(dist)
}