#' Calculo de Produccion de Energia Mensual
#'
#' @param fecha_recon a
#' @param rho10min d
#' @param vel_estelas f
#' @param curvascorregidas g
#' @param parqueEolico h
#' @param altCubo j
#' @param TempMin k
#' @param TempMax q
#' @param dt w
#' @param fechaSubida 
#' @param torres_MET 
#' @param tempExt 
#' @param dt Paso de Tiempo
#'
#' @return Energía generada mensualmente en MWh.
#' @export
#'
#' @examples #Empieza ejemplo

Energia_MensualVarAlt_sinPer <- function(fecha_recon, fechaSubida, torres_MET, rho10min, tempExt, vel_estelas, curvascorregidas, 
                                  parqueEolico, altCubo, Pot_Nominal, TempMin, TempMax, dt) {
  NT <- length(parqueEolico[[1]])
  #Se importan las fechas de la reconstrucción
  if (fechaSubida) {
    fechaRECON <- strptime(fecha_recon, "%Y-%m-%d %H:%M:%S", "")
  } else {
    fechaRECON <- as.POSIXlt(fecha_recon)
  }
  
  numTorres <- length(torres_MET)
  #Se calcula el día típico por mes de la densidad en sitio
  densidad_meses <- lapply(1:numTorres, function(n) {
    r <- as.POSIXct(torres_MET[[n]]$marcatemporal)
    DensidadesExt <- list()
    for (j in 1:length(rho10min[[n]]$alturas)) {
      rhom <- data_frame(fecha=r,rho=rho10min[[n]]$densidades[[j]])
      rhomeses <- split(rhom, format(rhom$fecha, "%m"))
      for (i in 1:length(rhomeses)) {
        df <- as.data.frame(matrix(ncol = 2,nrow = length(rhomeses[[i]]$rho)))
        df[,1] <- rhomeses[[i]]$fecha
        df[,2] <- rhomeses[[i]]$rho
        rhomeses[[i]] <- aggregate(V2~format(V1,"%H"), data=df, FUN=mean)
      }
      DensidadesExt[[j]] <- rhomeses
    }
    return(list(alturas=rho10min[[1]]$alturas,densidades=DensidadesExt))
  })
  
  #Se calcula el día típico por mes de la temperatura en sitio
  temperatura_meses <- lapply(1:numTorres, function(n) {
    r <- as.POSIXct(torres_MET[[n]]$marcatemporal)
    TemperaturasExt <- list()
    for (j in 1:length(tempExt[[n]]$alturas)) {
      temp <- data_frame(fecha=r,temp=tempExt[[n]]$temperaturas[[j]])
      tempmeses <- split(temp, format(temp$fecha, "%m"))
      for (i in 1:length(tempmeses)) {
        df <- as.data.frame(matrix(ncol = 2,nrow = length(tempmeses[[i]]$temp)))
        df[,1] <- tempmeses[[i]]$fecha
        df[,2] <- tempmeses[[i]]$temp
        tempmeses[[i]] <- aggregate(V2~format(V1,"%H"), data=df, FUN=mean)
      }
      TemperaturasExt[[j]] <- tempmeses
    }
    return(list(alturas=tempExt[[1]]$alturas,densidades=DensidadesExt))
  })
  
  #Se importa la curva de potencia corregida por densidad y se crea la función a trozos
  CurvasPotencia <- lapply(1:numTorres, function(n) {
    curvaPotencia <- list()
    for (i in 1:length(curvascorregidas[[n]]$alturas)) {
      curvaPotencia[[i]] <- approxfun(curvascorregidas[[n]]$curvascorregidas[[i]]$curvaPotencia$v, 
                                      curvascorregidas[[n]]$curvascorregidas[[i]]$curvaPotencia$P)
    }
    return(list(alturas=curvascorregidas[[1]]$alturas,Potencia=curvaPotencia))
  })
  
  #Se refieren las posiciones de las turbinas con la primera de la lista para generar ubicaciones en metros
  parqueEnMetros <- parqueEolico
  x_m <- rep(0,NT)
  y_m <- rep(0,NT)
  parqueEnMetros <- cbind(parqueEnMetros, x_m, y_m)
  for(i in 2:NT){
    longT1 <- parqueEnMetros[[2]][1]
    longT2 <- parqueEnMetros[[2]][i]
    latT1 <- parqueEnMetros[[3]][1]
    latT2 <- parqueEnMetros[[3]][i]
    sign_x <- sign(longT2 - longT1)
    sign_y <- sign(latT2 - latT1)
    ##El método distVincentyEllipsoid calcula la distancia basado en el elipsoide WGS84 como modelo del planeta Tierra
    vecturb <- c((sign_x*distVincentyEllipsoid(c(longT2,latT1),c(longT1,latT1))),
                 (sign_y*distVincentyEllipsoid(c(longT1,latT2),c(longT1,latT1))))
    parqueEnMetros[[5]][i] <- vecturb[1]
    parqueEnMetros[[6]][i] <- vecturb[2]
  }
  
  #Se asigna la información de cada torre a cada turbina según ubicación y radio de representatividad
  longTorre <- rep(0,numTorres)
  latTorre <- rep(0,numTorres)
  radioTorre <- rep(0,numTorres)
  indiceTorre <- rep(0,numTorres)
  for (i in 1:numTorres) {
    longTorre[i] <- torres_MET[[i]]$posicion[1]
    latTorre[i] <- torres_MET[[i]]$posicion[2]
    radioTorre[i] <- torres_MET[[i]]$RadioRep
    indiceTorre[i] <- i
  }
  posTorres <- data.frame(Longitud=longTorre, Latitud=latTorre, RadioRep=radioTorre, indiceTorre=indiceTorre)
  x_m <- rep(0,numTorres)
  y_m <- rep(0,numTorres)
  posTorres <- cbind(posTorres, x_m, y_m)
  
  for(i in 1:numTorres) {
    longTurb <- parqueEnMetros[[2]][1]
    longTorre <- posTorres$Longitud[i]
    latTurb <- parqueEnMetros[[3]][1]
    latTorre <- posTorres$Latitud[i]
    sign_x <- sign(longTorre - longTurb)
    sign_y <- sign(latTorre - latTurb)
    ##El método distVincentyEllipsoid calcula la distancia basado en el elipsoide WGS84 como modelo del planeta Tierra
    vecturb <- c((sign_x*distVincentyEllipsoid(c(longTorre,latTurb),c(longTurb,latTurb))),
                 (sign_y*distVincentyEllipsoid(c(longTurb,latTorre),c(longTurb,latTurb))))
    posTorres[[5]][i] <- vecturb[1]
    posTorres[[6]][i] <- vecturb[2]
  }
  
  indice_Torre <- rep(0,NT)
  parqueEnMetros <- cbind(parqueEnMetros,indice_Torre)
  for(i in 1:NT) {
    distancia <- rep(0,numTorres)
    x1 <- parqueEnMetros$x_m[i]
    y1 <- parqueEnMetros$y_m[i]
    for(j in 1:numTorres) {
      x2 <- posTorres$x_m[j]
      y2 <- posTorres$y_m[j]
      distancia[j] <- sqrt((x2 - x1)^2 + (y2 - y1)^2)/1000
    }
    indice <- which.min(distancia)
    if(distancia[indice] < posTorres$RadioRep[indice]) {
      parqueEnMetros$indice_Torre[i] <- indice
    } else {
      stop(paste0("La turbina ", i, " se encuentra por del radio de representatividad de las torres de medición en sitio."))
    }
  }
  
  #Genera la serie temporal de potencias para cada turbina
  withProgress(message = 'Calculando la Serie de Potencias en Resolucion Horaria. Espere por favor.', value = 0, {
    #Se prueba el algoritmo con la estela cambiando por dirección
    cores <- detectCores()
    registerDoParallel(makeCluster(cores))
    Potencia <- foreach(i=1:NT) %dopar% {
      tmp <- vel_estelas[,i]
      PoTurbina <- tmp
      for (j in 1:length(fechaRECON)) {
        MES <- format(fechaRECON[j], "%m")
        HORA <- as.numeric(format(fechaRECON[j], "%H"))+1
        altINDEX <- which(curvaPotencia[[parqueEnMetros$indice_Torre[i]]]$alturas==altCubo[[2]][i])
        if (temperatura_meses[[parqueEnMetros$indice_Torre[i]]]$temperaturas[[altINDEX]][[MES]][,2][HORA]<TempMin || 
            temperatura_meses[[parqueEnMetros$indice_Torre[i]]]$temperaturas[[altINDEX]][[MES]][,2][HORA]>TempMax) {
          PoTurbina[j] <- 0
        } else {
          P_temp <- curvaPotencia[[parqueEnMetros$indice_Torre[i]]]$Potencia[[altINDEX]](tmp[[j]])*
            (densidad_meses[[parqueEnMetros$indice_Torre[i]]]$densidades[[altINDEX]][[MES]][,2][HORA]/
               mean(rho10min[[parqueEnMetros$indice_Torre[i]]]$densidades[[altINDEX]]))
          if (is.na(P_temp)) {
            PoTurbina[j] <- 0
          } else {
            if (P_temp>Pot_Nominal) {
              PoTurbina[j] <- Pot_Nominal
            } else {
              PoTurbina[j] <- P_temp
            }
          }
        }
      }
      return(PoTurbina)
    }
    stopCluster(makeCluster(cores))
  })
  
  #Se crea un objeto con todas las series de datos de velocidad por turbina,
  #inicializada con la serie de velocidades de la primera turbina
  assign("Turbina_1", Potencia[[1]])
  POT_FINAL <- data.frame(cbind(Turbina_1))
  for (i in 2:NT){
    POT_FINAL[paste("Turbina_", i, sep = "")] <- Potencia[[i]]
  }
  
  #Calcula la energía como serie temporal en unidades de MWh
  E_FINAL = POT_FINAL*dt/1000
  E_FINAL[is.na(E_FINAL)] <- 0
  E_FINAL <- cbind(Fecha=as.POSIXct(fechaRECON), E_FINAL)
  
  return(E_FINAL)
}
