#Importar datos para reconstrucción
#-----------------------------
indicetorre <- read.csv(paste(getwd(), "/indiceTorre.csv", sep = ""))$x
med_sitio <- read.csv(paste(getwd(), "/Serie_Sitio_Horaria-Torre", indiceTorre, ".csv", sep = ""))
med_secomun <- read.csv(paste(getwd(), "/Serie_Fuente_Secundaria_PeriodoComun-Torre", indiceTorre, ".csv", sep = ""))

#Establecer limites del análisis
#----------------------------
#LIM_TIPO; Selecci?n tipo de límites.
        #1 = sectores con tamaño fijo
        #2 = sectores con igual cantidad de datos.
        #3 = sectores con tamaño variable

LIM_TIPO= 3 # 2, 3

if(LIM_TIPO==3){
  # L?mites con tama?o constante en direcci?n y velocidad
  Breaks = c(0,60,120,180,240,300,360)
  v_lim = c(0,3,6,9,12,15,25)

}
if(LIM_TIPO==2){
  # Para este caso se usan divisiones con el mismo numero de datos, es decir que hay bins mas peque?os en la direcci?n dominante
  Breaks= append(0,as.vector(ceiling(quantile(med_secomun$Direccion, c(.20,.40,.60,.8)))))
  Breaks= append(Breaks,360)

  v_lim = append(0, as.vector((quantile(med_secomun$Velocidad, c(.20,.40,.60,.8)))))
  v_lim = append(v_lim,25)
}
if(LIM_TIPO==3){
  # sectores con tama?o variable
  Breaks= c(0,30,150,240,360)
  v_lim = c(0,3,6,9,12,15,25)
}


#----------------------------
#Clasificación de datos

#Definicion de variables
      #CAT_D_I = Categoría de dirección, únicamente contiene índices
      #CAT_D_V = Categoría de dirección, con los valores de velocidad asociados a los indices
      #CAT_T_I = Lista de listas que contiene las categorías de dirección y las categorias de velocidad, únicamente los índices
      #CAT_V_I = Categoría de posiciones asociadas a velocidad, una para cada dirección de viento, índices únicamente
      #CAT_V_V = Lista que contiene los valores asociados a los indices de velocidad en la lista total


# Se categorizan todos los datos a partir de los lÍmites de direcciÓn y se crea un list con n posiciones igual a numero de bins utilizado para dirección
CAT_D_I = list()
for(i in 1:(length(Breaks)-1)){
  CAT_D_I[[i]] = which(med_secomun$Direccion>=Breaks[i] &med_secomun$Direccion<Breaks[i+1])
}

#Valores reales en clasificación por dirección, información de referencia
CAT_D_V_NREL=list()
for(j in 1:length(CAT_D_I)){
  aux=c()
  for(i in 1:length(CAT_D_I[[j]])){
    aux[i]= med_secomun$Velocidad[CAT_D_I[[j]][i]]
  }
  CAT_D_V_NREL[[j]]=aux
}

#Valores reales en clasificación por dirección, información real
CAT_D_V_REAL=list()
for(j in 1:length(CAT_D_I)){
  aux=c()
  for(i in 1:length(CAT_D_I[[j]])){
    aux[i]= med_sitio$Velocidad[CAT_D_I[[j]][i]]
  }
  CAT_D_V_REAL[[j]]=aux
}


# Para cada una de las clases de dirección se realiza categorización por velocidad
CAT_T_I = list()
for(j in 1:length(CAT_D_V_NREL)){
  CAT_V_I=list()
  for(i in 1:(length(v_lim)-1)){
    CAT_V_I[[i]]=which(as.vector(CAT_D_V_NREL[[j]])>=v_lim[i]& as.vector(CAT_D_V_NREL[[j]])<v_lim[i+1])
  }
  CAT_T_I[[j]]=CAT_V_I
}

# Creación de matrices de comparación MCP, en este caso no se presentan matrices sino listas con valores de velocidad
# Matriz datos de referencia
CAT_T_V_NREL=list()
for(k in 1:length(CAT_D_V_NREL)){
V_AUX =CAT_D_V_NREL[[k]]
list_aux=list()
    for(j in 1:length(CAT_T_I[[k]])){
        aux=c()

            for(i in 1:length(CAT_T_I[[k]][[j]])){

              aux[i]=V_AUX[CAT_T_I[[k]][[j]][i]]

            }

        list_aux[[j]]=aux
    }
CAT_T_V_NREL[[k]]=list_aux
}

# Matriz de datos reales
CAT_T_V_REAL=list()
for(k in 1:length(CAT_D_V_REAL)){
  V_AUX =CAT_D_V_REAL[[k]]
  list_aux=list()
  for(j in 1:length(CAT_T_I[[k]])){
    aux=c()

    for(i in 1:length(CAT_T_I[[k]][[j]])){

      aux[i]=V_AUX[CAT_T_I[[k]][[j]][i]]

    }

    list_aux[[j]]=aux
  }
  CAT_T_V_REAL[[k]]=list_aux
}




#----------------------------
#Cálculo parámetros MCP

MCP_P_T_NREL =list()
for(j in 1:length(CAT_T_V_NREL)){
aux1=list()
aux2=list()
  for(i in 1:length(CAT_T_V_NREL[[2]])){
    aux1[[i]]=mean(CAT_T_V_NREL[[2]][[i]])
    aux2[[i]]=sd(CAT_T_V_NREL[[2]][[i]])
  }
  MCP_PARAM=list(mean=aux1,sd=aux2)
MCP_P_T_NREL[[j]]=MCP_PARAM
}


MCP_P_T_REAL =list()
for(j in 1:length(CAT_T_V_REAL)){
  aux1=list()
  aux2=list()
  for(i in 1:length(CAT_T_V_REAL[[2]])){
    aux1[[i]]=mean(CAT_T_V_REAL[[2]][[i]])
    aux2[[i]]=sd(CAT_T_V_REAL[[2]][[i]])
  }
  MCP_PARAM=list(mean=aux1,sd=aux2)
  MCP_P_T_REAL[[j]]=MCP_PARAM
}


#----------------------------
#Importar datos históricos - LONG-RUN
LongRun_data <- read.csv(paste(getwd(), "/Serie_Fuente_Secundaria-Torre", indiceTorre, ".csv", sep = ""))
LONGRUN = list(FECHA=LongRun_data$Fechas,V_NREL=LongRun_data$Velocidad,D_NREL=LongRun_data$Direccion)

aux_dir=c()
aux_vel=c()
aux_date=c()

#
for(j in 1:length(LONGRUN$D_NREL)){

  #Clasificación por dirección. Dir, almacena el sector en el que aparecen el valor
  cont=1
  Dir=0
  for(i in 1:(length(Breaks)-1)){

    if(LONGRUN$D_NREL[j]>=Breaks[i]& LONGRUN$D_NREL[j]<Breaks[i+1]){
      Dir=cont
      break()
    }
    else{
      Dir = "A"
    }
    cont=cont+1
  }

  #Clasificación por velocidad. Vel, almacena el sector en el que aparecen el valor
  cont=1
  Vel=0
  for(i in 1:(length(v_lim)-1)){

    if(LONGRUN$V_NREL[j]>=v_lim[i]& LONGRUN$V_NREL[j]<v_lim[i+1]){
      Vel=cont
      break()
    } else {
      Vel = "A"
    }
    cont=cont+1
}

  if(Dir=="A" |Vel=="A"){
    S_Y=1
    S_X=1
    MEAN_Y=1
    MEAN_X=1
    
  } else {
  # Se extraen los parámetros para cada valor en la serie LONGRUN
  S_Y=MCP_P_T_REAL[[Dir]]$sd[[Vel]]
  S_X=MCP_P_T_NREL[[Dir]]$sd[[Vel]]
  MEAN_Y =MCP_P_T_REAL[[Dir]]$mean[[Vel]]
  MEAN_X =MCP_P_T_NREL[[Dir]]$mean[[Vel]]
  }

# Se calcula el nuevo valor de direcci?n
  V_LT =(MEAN_Y-((S_Y/S_X)*MEAN_X))+((S_Y/S_X)*LONGRUN$V_NREL[j])
  aux_dir[j]= LONGRUN$D_NREL[j]
  aux_vel[j]= V_LT
  aux_date [j]= LONGRUN$FECHA[j]
}

aux_vel <- na.locf(aux_vel)
for(i in 1:length(aux_vel)){
  if(as.numeric(is.na(aux_vel[i]))==1 | aux_vel[i]<=0){
    aux_vel[i]=mean(aux_vel[i-1],aux_vel[i+1])
  }
}


##---------------------
#Generación de matrices
matrizREAL = matrix(nrow = (length(v_lim)-1), ncol = (length(Breaks)-1))
aux=c()
for(j in 1:length(CAT_T_V_REAL)){
  for(i in 1:length(CAT_T_V_REAL[[j]])){
    aux[i]=((length(CAT_T_V_REAL[[j]][[i]])*100)/length(med_sitio$Velocidad))
  }
  matrizREAL[,j]=aux
}

matrizREF = matrix(nrow = (length(v_lim)-1), ncol = (length(Breaks)-1))
aux=c()
for(j in 1:length(CAT_T_V_NREL)){
  for(i in 1:length(CAT_T_V_NREL[[j]])){
    aux[i]=((length(CAT_T_V_NREL[[j]][[i]])*100)/length(med_secomun$Velocidad))
  }
  matrizREF[,j]=aux
}


##----------------------
# Guardar datos
titulos=c("Fechas","Vel_RC","Direccion")
TABLE=data.frame(as.POSIXct(LONGRUN$FECHA),aux_vel,aux_dir)
names(TABLE)=titulos
write.csv(x = TABLE,file = paste(getwd(), "/RECONSTRUCCION-Torre", indiceTorre, ".csv", sep = ""))
