#' Correccion de Curvas de Potencia y Coeficiente de empuje por densidad
#'
#' @param curvpot q
#' @param P_r w
#' @param V_out e
#' @param rhocurva r
#' @param rhositio t
#'
#' @return u
#' @export
#'
#' @examples
#' #Empieza ejemplo
curvaCorreccion <- function(curvpot, P_r, V_out, rhocurva, rhositio)
{
  if(missing(curvpot)) stop("La curva de potencia 'curvpot' es obligatoria")
  if(missing(P_r)) stop("La potencia nominal 'P_r' de la turbina eólica es obligatoria")
  if(missing(V_out)) stop("La velocidad terminal 'V_out' de la turbina eólica es obligatoria")
  if(missing(rhositio)) stop("La densidad en el sitio 'rhositio' es obligatoria")
  if(missing(rhocurva)) rhocurva <- 1.225

  if(class(curvpot)!="curvpot") stop(substitute(curvpot), " no es un objeto de curva de potencia")
  if(!is.numeric(P_r)) stop("'P_r' debe ser un valor numérico")
  if(!is.numeric(V_out)) stop("'V_out' debe ser un valor numérico")
  if(!is.numeric(rhositio)) stop("'rhositio' debe ser un valor numérico")
  if(!is.numeric(rhocurva)) stop("'rhocurva' debe ser un valor numérico")

  #Busca la posición desde la cual empieza la potencia nominal
  n_r <- match(P_r,curvpot$P)
  #Calcula el coeficiente de potencia
  #(no tiene en cuenta densidad y area del rotor, que son constantes y no afectan la ubicación del máximo)
  cp <- curvpot$P/((curvpot$v)^3)
  #Busca la posición del máximo coeficiente de potencia
  n_design <- which.max(cp)
  n_final <- length(curvpot$v)
  #Se aplica la corrección de densidad según el rango de velocidades
  db <- (1/3)/(n_r - n_design)
  b <- seq((1/3)+db, 2/3, by = db)
  curvPotencia <- curvpot
  curvPotencia$ct <- NULL
  curvPotencia$v[1:n_design] <- curvpot$v[1:n_design]*((rhocurva/rhositio)^(1/3))
  curvPotencia$v[(n_design+1):n_r] <- curvpot$v[(n_design+1):n_r]*((rhocurva/rhositio)^(b))
  curvPotencia$v[(n_r+1):n_final] <- curvpot$v[(n_r+1):n_final]*((rhocurva/rhositio)^(2/3))
  #Se reemplazan los datos correspondientes a velocidades superiores a la de salida
  sup <- min(which(curvPotencia$v > V_out))
  for (i in sup:length(curvPotencia$v)) {
    curvPotencia$v[i] <- V_out
  }

  #Se genera una lista aparte para el coeficiente de empuje ya que el desplazamiento sigue otro criterio
  curvCT <- curvpot
  curvCT$P <- NULL
  dbt <- ((1/3)-(1/8))/(n_r - n_design)
  bt <- seq((1/8)+dbt, 1/3, by = dbt)
  curvCT$v[1:n_design] <- curvpot$v[1:n_design]*((rhocurva/rhositio)^(1/8))
  curvCT$v[(n_design+1):n_r] <- curvpot$v[(n_design+1):n_r]*((rhocurva/rhositio)^(bt))
  curvCT$v[(n_r+1):n_final] <- curvpot$v[(n_r+1):n_final]*((rhocurva/rhositio)^(1/3))
  supCT <- min(which(curvCT$v > V_out))
  for (i in sup:length(curvPotencia$v)) {
    curvCT$v[i] <- V_out
  }

  r <- list(curvaPotencia = curvPotencia, curvaCT = curvCT)

  return(r)
}
