#' Title
#'
#' @param torre a
#' @param v.serie s
#' @param metodo d
#' @param digits g
#'
#' @return a
#' @export
#'
#' @examples #Ejemplo

leypot <- function(torre, v.serie, metodo=c("justus", "hellman", "potlm"), digits=3)
  {
	if(class(torre)!="torre") stop(substitute(torre), " no es un objeto torre")
	num.series <- length(torre$series)
	if(missing(v.serie)) stop("Por favor seleccione una o más series en 'v.serie'")
	if(!is.numeric(v.serie)) if(!(length(v.serie)==1 && any(v.serie=="all"))) v.serie <- match(v.serie, names(torre$series))
	if(any(is.na(v.serie))) stop("'v.serie' no fue encontrado")
	if(any(v.serie<=0) || any(v.serie>num.series)) stop("'v.serie' no fue encontrado")
	for(i in 1:length(v.serie)) if(is.null(torre$series[[v.serie[i]]]$data$v.prom)) stop("La serie ", v.serie[i], " no contiene datos de velocidad promedio de viento")
	if(missing(metodo) || length(metodo)!=1) stop("Seleccione un metodo: 'justus' 'hellman' 'potlm'")

	alpha <- NULL
	v1 <- torre$series[[v.serie[1]]]$data$v.prom
	v1[which(v1==0)] <- NA
	v1 <- na.locf(v1)
	h1 <- torre$series[[v.serie[1]]]$altura

	if(metodo=="justus") { #Método de Justus-Mikhail
	  if(length(v.serie)<1) stop("El método 'justus' requiere una serie de datos a una altura")
	  if(length(v.serie)>1) {
	    warning("El método 'justus' utiliza una serie de datos a una sola altura - solo la primera serie de 'v.serie' será utilizada", call.=FALSE)
	  }

	  alpha <- (0.37-0.088*log(v1))/(1-0.088*log(h1/10))
	  attr(alpha, "unidades") <- c("-", attr(torre$series[[v.serie[1]]]$data$v.prom, "unidad"))
	}

	else if(metodo=="hellman") {	# hellmann
		if(length(v.serie)<2) stop("El método 'hellman' requiere dos series de datos de velocidad a diferentes alturas")
		if(length(v.serie)>2) {
			warning("El método 'hellman' utiliza dos series de datos (alturas) - solo las dos primeras series de 'v.serie' serán utilizadas", call.=FALSE)
			v.serie <- v.serie[1:2]
		}

		v2 <- torre$series[[v.serie[2]]]$data$v.prom
		v2[which(v2==0)] <- NA
		v2 <- na.locf(v2)
		h2 <- torre$series[[v.serie[2]]]$altura

		if(h1==h2) stop("Las series tienen la misma altura, no es posible la extrapolación")

		alpha <- log(v2 / v1) / log(h2 / h1)
		attr(alpha, "unidades") <- c("-", attr(torre$series[[v.serie[1]]]$data$v.prom, "unidad"))
		
	} else {	# logreg
		if(length(v.serie)<2) stop("El método 'potlm' requiere dos series de datos (alturas)")
	  assign("V_Vr1", log(v1))
	  vrel <- data.frame(cbind(V_Vr1))
	  assign("h_hr1", log(h1))
	  hrel <- data.frame(cbind(h_hr1))
		for(i in 2:length(v.serie)) {
		  vrel[paste("V_Vr", i, sep = "")] <- log(torre$series[[v.serie[i]]]$data$v.prom)
		  hrel[paste("h_hr", i, sep = "")] <- log(torre$series[[v.serie[i]]]$altura)
		  vrel[[i]][which(!is.finite(vrel[[i]]))] <- NA
		  vrel[[i]] <- na.locf(vrel[[i]])
		}

	  alpha <- v1
	  for(i in 1:length(v1)) {
	    vp <- c(0,0)
	    hp <- c(0,0)
	    for(j in 1:(length(v.serie))) {
	      vp[j] <- vrel[[j]][i]
	      hp[j] <- hrel[[j]]
	    }
	    potlm <- lm(vp ~ hp)
	    alpha[i] <- potlm$coefficients[2]
	  }
	  attr(alpha, "unidades") <- c("-", attr(torre$series[[v.serie[1]]]$data$v.prom, "unidad"))
	}

	alpha[which(!is.finite(alpha))] <- NA
	alpha <- na.locf(alpha)
	alpha[which(alpha<0)] <- NA
	alpha <- na.locf(alpha)
	alpha[which(alpha>0.352)] <- NA
	alpha <- na.locf(alpha)
	alpha <- list(alpha=alpha, h.ref=h1)
	attr(alpha, "call") <- list(func="alpha", torre=deparse(substitute(torre)), v.serie=v.serie, metodo=metodo, digits=digits)

	class(alpha) <- "alpha"

	return(alpha)
}
