#' Graficar mapa o imagen satelital de turbinas
#'
#' @param parque Turbinas del parque eólico
#' @param alejar Alejar zoom del mapa
#' 
#' @details Esta función está basada en el paquete RgoogleMaps de Markus Loecher, el cual usa la API de Google Static Maps.
#'
#' @return Mapa
#' @export
#'
#' @examples ## Empieza ejemplo

mapaParque <- function (parque, alejar)
{
  register_google(key = "AIzaSyCezfyAi6QVKkyhNTLB0y8jtQBT52G0JoM")
  bound <- function(zoom) return(0.0025*2^(14-zoom))
  lon <- rep(0,length(parque[[1]]))
  lat <- rep(0,length(parque[[1]]))
  for (i in 1:length(parque[[1]])) {
    lon[i] <- parque[[2]][i]
    lat[i] <- parque[[3]][i]
  }
  center = c(mean(lon), mean(lat));
  rangmax <- max(c((range(lon)[2]-range(lon)[1]),(range(lat)[2]-range(lat)[1])))
  if (((range(lon)[2]-range(lon)[1])/(range(lat)[2]-range(lat)[1]))<20) {
    if (((range(lon)[2]-range(lon)[1])/(range(lat)[2]-range(lat)[1]))>0.05) {
      if (alejar == TRUE) {
        zoom <- min(calc_zoom(range(lon), range(lat)))-3;
      }
      else zoom <- min(calc_zoom(range(lon), range(lat)))-1;
    }
  } else {
    if (alejar == TRUE) {
      zoom <- min(calc_zoom(range(lon), range(lat)))-2;
    }
    else zoom <- min(calc_zoom(range(lon), range(lat)));
  }
  dataParque <- data.frame(numTurb=parque[[1]],lon=lon,lat=lat)
  dataParque$image <- paste0(getwd(),"/www/rojo.png")
  Mapa <- get_googlemap(center=center, zoom=zoom, maptype = "satellite", source="google", language="es-ES")
  mapaPuntos <- ggmap(Mapa, extent = "panel", legend = "bottomright")
  mapaPuntos +
    scale_x_continuous(limits = c(center[1]-0.5*rangmax-bound(zoom=zoom), 
                                  center[1]+0.5*rangmax+bound(zoom=zoom)), expand = c(0, 0)) +
    scale_y_continuous(limits = c(center[2]-0.5*rangmax-bound(zoom=zoom), 
                                  center[2]+0.5*rangmax+bound(zoom=zoom)), expand = c(0, 0)) +
    geom_image(aes(image=image), size=0.035, data = dataParque) +
    geom_text(aes(label=numTurb), col = "red", size=8, hjust=1, vjust=0, data = dataParque) +
    theme(axis.title.x=element_blank(), axis.title.y=element_blank(),
          axis.text.x=element_blank(), axis.text.y=element_blank(),
          axis.ticks.x=element_blank(), axis.ticks.y=element_blank())
}
