#' Graficar mapa o imagen satelital de torres meteorológicas
#'
#' @description  Grafica un mapa o imagen saltelital de la posición de la torre meteorológica
#'
#' @param torre Lista de torres meteorológicas del parque creadas por [torre].
#' @param alejar Alejar zoom del mapa
#'
#' @details Esta función está basada en el paquete RgoogleMaps de Markus Loecher, el cual usa la API de Google Static Maps.
#'
#' @return Mapa
#' @export
#'
#' @examples ## Empieza ejemplo

mapaTorre <- function (torres, alejar)
{
  register_google(key = "AIzaSyCezfyAi6QVKkyhNTLB0y8jtQBT52G0JoM")
  if (length(torres)>1) {
    bound <- function(zoom) return(0.005*2^(14-zoom))
    lon <- rep(0,length(torres))
    lat <- rep(0,length(torres))
    nombres <- rep(0,length(torres))
    for (i in 1:length(torres)) {
      lon[i] <- torres[[i]]$posicion[1]
      lat[i] <- torres[[i]]$posicion[2]
      nombres[i] <- torres[[i]]$descripcion
    }
    center = c(mean(lon), mean(lat));
    rangmax <- max(c((range(lon)[2]-range(lon)[1]),(range(lat)[2]-range(lat)[1])))
    if (((range(lon)[2]-range(lon)[1])/(range(lat)[2]-range(lat)[1]))<20) {
      if (((range(lon)[2]-range(lon)[1])/(range(lat)[2]-range(lat)[1]))>0.05) {
        if (alejar == TRUE) {
          zoom <- min(calc_zoom(range(lon), range(lat)))-4;
        }
        else zoom <- min(calc_zoom(range(lon), range(lat)))-2;
      }
    } else {
      if (alejar == TRUE) {
        zoom <- min(calc_zoom(range(lon), range(lat)))-3;
      }
      else zoom <- min(calc_zoom(range(lon), range(lat)))-1;
    }
    dataParque <- data.frame(nomTorre=nombres,lon=lon,lat=lat)
    Mapa <- get_googlemap(center=center, zoom=zoom, maptype = "satellite", source="google", language="es-ES")
    mapaPuntos <- ggmap(Mapa, extent = "panel", legend = "bottomright")
    mapaPuntos +
      scale_x_continuous(limits = c(center[1]-0.5*rangmax-bound(zoom=zoom), 
                                    center[1]+0.5*rangmax+bound(zoom=zoom)), expand = c(0, 0)) +
      scale_y_continuous(limits = c(center[2]-0.5*rangmax-bound(zoom=zoom), 
                                    center[2]+0.5*rangmax+bound(zoom=zoom)), expand = c(0, 0)) +
      geom_point(aes(x = lon, y = lat), col = "red", size=4,  data = dataParque) +
      geom_text(aes(label=nomTorre), col = "red", size=7, hjust=1, vjust=1, data = dataParque) +
      theme(axis.title.x=element_blank(), axis.title.y=element_blank(),
            axis.text.x=element_blank(), axis.text.y=element_blank(),
            axis.ticks.x=element_blank(), axis.ticks.y=element_blank())
  } else {
    bound <- function(zoom) return(0.015*2^(14-zoom))
    lon <- torres[[1]]$posicion[1]
    lat <- torres[[1]]$posicion[2]
    nombre <- torres[[1]]$descripcion
    center = c(lon, lat)
    if (alejar == TRUE) {
      zoom <- 12
    }
    else {
      zoom <- 14
    }
    dataParque <- data.frame(nomTorre=nombre,lon=lon,lat=lat)
    Mapa <- get_googlemap(center=center, zoom=zoom, maptype = "satellite", source="google", language="es-ES")
    mapaPuntos <- ggmap(Mapa, extent = "panel", legend = "bottomright")
    mapaPuntos +
      scale_x_continuous(limits = c(min(lon)-bound(zoom=zoom), max(lon)+bound(zoom=zoom)), expand = c(0, 0)) +
      scale_y_continuous(limits = c(min(lat)-bound(zoom=zoom), max(lat)+bound(zoom=zoom)), expand = c(0, 0)) +
      geom_point(aes(x = lon, y = lat), col = "red", size=4,  data = dataParque) +
      geom_text(aes(label=nomTorre), col = "red", size=8, hjust=1, vjust=1, data = dataParque) +
      theme(axis.title.x=element_blank(), axis.title.y=element_blank(),
            axis.text.x=element_blank(), axis.text.y=element_blank(),
            axis.ticks.x=element_blank(), axis.ticks.y=element_blank())
  }
}
