#' Mapa del Trazado Eléctrico
#'
#' @param parque Turbinas del parque eólico
#' @param PCC Coordenadas del Punto de Conexión Común
#' @param Cableado Cables del Trazado Eléctrico
#' @param alejar Alejar zoom del mapa
#'
#' @return Mapa
#' @export
#'
#' @examples ## Empieza ejemplo

mapaTrazado <- function (parque, PCC, Cableado, alejar) {
  register_google(key = "AIzaSyCezfyAi6QVKkyhNTLB0y8jtQBT52G0JoM")
  bound <- function(zoom) return(0.003*2^(14-zoom))
  lon <- rep(0,length(parque[[1]]))
  lat <- rep(0,length(parque[[1]]))
  for (i in 1:length(parque[[1]])) {
    lon[i] <- parque[[2]][i]
    lat[i] <- parque[[3]][i]
  }
  limlon <- c(lon,PCC[1])
  limlat <- c(lat,PCC[2])
  center = c(mean(limlon), mean(limlat));
  rangmax <- max(c((range(limlon)[2]-range(limlon)[1]),(range(limlat)[2]-range(limlat)[1])))
  if (((range(limlon)[2]-range(limlon)[1])/(range(limlat)[2]-range(limlat)[1]))<20) {
    if (((range(limlon)[2]-range(limlon)[1])/(range(limlat)[2]-range(limlat)[1]))>0.05) {
      if (alejar == TRUE) {
        zoom <- min(calc_zoom(range(limlon), range(limlat)))-3;
      }
      else zoom <- min(calc_zoom(range(limlon), range(limlat)))-1;
    }
  } else {
    if (alejar == TRUE) {
      zoom <- min(calc_zoom(range(limlon), range(limlat)))-2;
    }
    else zoom <- min(calc_zoom(range(limlon), range(limlat)));
  }
  dataParque <- data.frame(numTurb=parque[[1]],lon=lon,lat=lat)
  dataParque$image <- paste0(getwd(),"/www/rojo.png")
  Mapa <- get_googlemap(center=center, zoom=zoom, maptype = "satellite", source="google", language="es-ES")
  mapaPuntos <- ggmap(Mapa, extent = "panel", legend = "bottomright")
  PCComun <- data.frame(PCC="PCC",lon=PCC[1],lat=PCC[2])
  mapaGraf <- mapaPuntos +
    scale_x_continuous(limits = c(center[1]-0.5*rangmax-bound(zoom=zoom), 
                                  center[1]+0.5*rangmax+bound(zoom=zoom)), expand = c(0, 0)) +
    scale_y_continuous(limits = c(center[2]-0.5*rangmax-bound(zoom=zoom), 
                                  center[2]+0.5*rangmax+bound(zoom=zoom)), expand = c(0, 0)) +
    geom_image(aes(image=image), size=0.035, data = dataParque) +
    geom_text(aes(label=numTurb), col = "red", size=8, hjust=1, vjust=0, data = dataParque) +
    geom_point(aes(x = lon, y = lat), col = "red", size=4,  data = PCComun) +
    geom_text(aes(label=PCC), col = "red", size=8, hjust=1, vjust=1, data = PCComun) +
    theme(axis.title.x=element_blank(), axis.title.y=element_blank(),
          axis.text.x=element_blank(), axis.text.y=element_blank(),
          axis.ticks.x=element_blank(), axis.ticks.y=element_blank())
  
  CABLES <- list()
  for (i in 1:length(Cableado)) {
    cabtemp <- Cableado[[i]]
    comp <- is.na(cabtemp)
    cabtemp <- cabtemp[!comp]
    lonC <- lon[cabtemp]
    lonC <- c(lonC,PCC[1])
    latC <- lat[cabtemp]
    latC <- c(latC,PCC[2])
    posCable <- data.frame(lon=lonC,lat=latC)
    CABLES[[i]] <- posCable
  }
  
  for(i in 1:length(Cableado)) {
    mapaGraf <- mapaGraf + geom_path(aes(x = lon, y = lat), size=1, col = "red", data = CABLES[[i]])
  }
  
  return(mapaGraf)
}