#' Title
#'
#' @param torre q
#' @param tmp.serie w
#' @param press.serie e
#' @param hum.serie r
#' @param h.cubo t
#' @param digits y
#' @param print u
#'
#' @return Devuelve la serie temporal de densidades medida en sitio
#' @export
#'
#' @examples
#' #Empieza ejemplo

rhositio <- function(torre, tmp.serie, press.serie, hum.serie, h.cubo, digits=3, print=TRUE)
{
  if(class(torre)!="torre") stop(substitute(torre), " no es un objeto torre.")
  num.series <- length(torre$series)
  if(missing(tmp.serie)) stop("Por favor seleccione una serie de temperatura medida en sitio.")
  if(!is.numeric(tmp.serie)) if(!(length(tmp.serie)==1 && any(tmp.serie=="all"))) tmp.serie <- match(tmp.serie, names(torre$series))
  if(any(is.na(tmp.serie))) stop("Serie de temperatura medida en sitio no fue encontrada.")
  if(any(tmp.serie<=0) || any(tmp.serie>num.series)) stop("Serie de temperatura medida en sitio no fue encontrada.")
  for(i in 1:length(tmp.serie)) if(is.null(torre$series[[tmp.serie[i]]]$data$tmp)) stop("La serie ", tmp.serie[i], " no contiene datos de temperatura de viento.")
  if(!is.numeric(press.serie)) press.serie <- match(press.serie, names(torre$series))
  if(is.na(press.serie)) stop("Serie de presión medida en sitio no fue encontrada.")
  if(press.serie<=0 || press.serie>num.series) stop("Serie de presión medida en sitio no fue encontrada.")
  if(is.null(torre$series[[press.serie]]$data$press)) stop("La serie de presión no contiene datos de presión atmosférica.")
  if(!is.numeric(hum.serie)) hum.serie <- match(hum.serie, names(torre$series))
  if(is.na(hum.serie)) stop("Serie de humedad medida en sitio no fue encontrada")
  if(hum.serie<=0 || hum.serie>num.series) stop("Serie de humedad medida en sitio no fue encontrada.")
  if(is.null(torre$series[[hum.serie]]$data$hum)) stop("Serie de humedad medida en sitio no fue encontrada.")
  if(missing(h.cubo)) stop("Por favor, ingrese la altura del cubo de las turbinas eólicas del parque.")

  tmp <- torre$series[[tmp.serie]]$data$tmp
  hum <- torre$series[[hum.serie]]$data$hum
  press <- torre$series[[press.serie]]$data$press
  href <- torre$series[[tmp.serie]]$altura

  #Conversión de ºC a K
  T_ref <- 273.15 + tmp

  #Interpolación de temperatura y presión según ISO 2533
  T_10min <- T_ref - 6.5*((h.cubo-href)/1000)
  B_10min <- press*((T_10min/T_ref)^(9810/(6.5*287.058)))

  #Cálculo de la presión del agua P_w
  P_w <- 0.0000205*exp(0.0631846*T_10min)
  #Cálculo de densidad
  rho_10min <- (1/T_10min)*((B_10min/2.8705)-(hum/100)*P_w*((1/287.05)-(1/461.5)))

  return(rho_10min)

}
